////////////////////////////////////////////////////////////////////////////////
// TWizard                                                                    //
////////////////////////////////////////////////////////////////////////////////
// Visible graphic component for easy making wizardforms etc.                 //
// Based on TgraphicControl                                                   //
////////////////////////////////////////////////////////////////////////////////
// Version 1.00 Beta                                                          //
// Created                    : 25/07/1998                                    //
// Last modified              : 25/07/1998                                    //
////////////////////////////////////////////////////////////////////////////////
// R. Andr Inghilleri                                                        //
// andre@norleas.no                                                           //
////////////////////////////////////////////////////////////////////////////////
// IMPORTANT NOTICE :                                                         //
//                                                                            //
//                                                                            //
// This program is FreeWare                                                   //
//                                                                            //
// Please do not release modified versions of this source code.               //
// If you've made any changes that you think should have been there,          //
// feel free to submit them to me.                                            //
////////////////////////////////////////////////////////////////////////////////
//  REVISIONS :                                                               //
//                                                                            //
////////////////////////////////////////////////////////////////////////////////


unit Wizard;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, comctrls;

type
  TPicControl = (Large_x1, Small_x3);

  TWizard = class(TGraphicControl)
  private
    FPicture: TPicture;
    FAlignment: TAlignment;
    FPicControl: TPicControl;
    FTransparent: Boolean;
    procedure PictureChanged(Sender: TObject);
    procedure SetAlignment(Value: TAlignment);
    procedure SetPicture(Value: TPicture);
    procedure SetPicControl(Value: TPicControl);
    procedure SetTransparent(Value: Boolean);
    procedure CMTextChanged(var Message: TMessage); message CM_TEXTCHANGED;
  protected
    function DestRect(pic_no,pic_tot:integer): TRect;
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    property Canvas;
  published
    property Align;
    property Alignment: TAlignment read FAlignment write SetAlignment default taCenter;
    property Caption;
    property Color;
    property DragCursor;
    property DragMode;
    property Enabled;
    property Font;
    property ParentColor;
    property ParentFont;
    property ParentShowHint;
    property Picture: TPicture read FPicture write SetPicture;
    property PictureControl: TPicControl read FPicControl write SetPicControl default Small_x3;
    property PopupMenu;
    property ShowHint;
    property Transparent: Boolean read FTransparent write SetTransparent default True;
    property Visible;
    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDrag;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnStartDrag;
  end;

procedure Register;

implementation

{ TWizard }

constructor TWizard.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := ControlStyle + [csReplicatable];
  FPicture := TPicture.Create;
  FPicture.OnChange := PictureChanged;
  Width := 100;
  Height := 100;
  color := clTeal;
  transparent:=true;
  alignment:=taLeftJustify;
  picturecontrol:=Small_x3;
  inherited Align := alLeft;
end;

destructor TWizard.Destroy;
begin
  FPicture.Free;
  inherited Destroy;
end;

procedure TWizard.PictureChanged(Sender: TObject);
begin
  Invalidate;
end;

procedure TWizard.SetAlignment(Value: TAlignment);
begin
  FAlignment := Value;
  Invalidate;
end;

procedure TWizard.SetPicture(Value: TPicture);
begin
  FPicture.Assign(Value);
end;

procedure TWizard.SetPicControl(value: TPicControl);
begin
  if FPicControl <> value then
  begin
    FPicControl := value;
    invalidate;
  end;
end;

procedure TWizard.SetTransparent(Value: Boolean);
begin
  if Value <> FTransparent then
  begin
    FTransparent := Value;
    invalidate;
  end;
end;


procedure TWizard.Paint;
const
  Alignments: array[TAlignment] of Word = (DT_CENTER, DT_LEFT, DT_RIGHT);
var picture_number,picture_count, text_height, text_top:integer;
    drawstyle:word;
    rectb:trect;
begin
  if PictureControl=Small_x3 then picture_count:=3
                             else picture_count:=1;
  rectb:=Rect(5, 0, 90, 50);
  Canvas.Font := Font;
  with Canvas do begin
    Brush.Color := Color;
    Pen.Style := psclear;
    Brush.Style := bssolid;
    Rectangle(0, 0, Width, Height);
    Brush.Style := bsclear;
  end;
  if Picture.Graphic <> nil then Picture.Graphic.Transparent := transparent;
  DrawStyle := Alignments[FAlignment] or DT_WORDBREAK;
  text_height:=DrawText(Canvas.Handle, PChar(caption), -1, Rectb, DT_CALCRECT or drawstyle);
  text_top:=clientheight-10-text_height;
  rectb:=Rect(5, text_top, 90,text_top+text_height);
  try
    with inherited Canvas do begin
      DrawText(Canvas.Handle, PChar(caption), -1, Rectb, drawstyle);
      for picture_number:=1 to picture_count do
        StretchDraw(DestRect(picture_number,picture_count), Picture.Graphic);
    end;
  finally
   { FDrawing := Save;  }
  end;
end;

function TWizard.DestRect(pic_no,pic_tot:integer): TRect;
var pic_left,pic_top:integer;
    verdi           :real;
begin
  pic_left:=0;pic_top:=0;verdi:=0;
  if pic_tot=3 then begin
    case pic_no of
      1: begin
           pic_left:=10;
           pic_top:=25;
         end;
      2: begin
           pic_left:=55;
           pic_top:=25;
         end;
      3: begin
           pic_left:=30;
           pic_top:=65;
         end;
    end;
    Result := Rect(pic_left, pic_top, 38+pic_left, 38+pic_top);
  end else if pic_tot=1 then begin
    if (picture.width/width)>(picture.Height/Height)
      then verdi:=picture.width/(width-10)
      else verdi:=picture.height/height;
    Result := Bounds((Width-round(Picture.Width/verdi)) div 2, 10, round(Picture.Width/verdi), round(Picture.Height/verdi))
  end;
end;

procedure TWizard.CMTextChanged(var Message: TMessage);
begin
  Invalidate;
end;


// Register the component


procedure Register;
begin
  RegisterComponents('Graphics', [TWizard]);
end;

end.
